Learn R Programming

spatemR (version 1.2.0)

print.summary.GEESAR: Print Method for Summary of GEESAR Models

Description

This method prints a formatted summary of a 'summary.GEESAR' object, including details of the model coefficients, rho, dispersion, and other statistics.

Usage

# S3 method for summary.GEESAR
print(x, ...)

Value

Print a summary for the specified Generalized Spatial Autoregresive Model class.

Arguments

x

An object of class 'summary.GEESAR'.

...

Additional arguments (currently unused).