print.summary.GEESAR: Print Method for Summary of GEESAR Models
Description
This method prints a formatted summary of a 'summary.GEESAR' object,
including details of the model coefficients, rho, dispersion, and other statistics.
Usage
# S3 method for summary.GEESAR
print(x, ...)
Value
Print a summary for the specified Generalized Spatial Autoregresive Model class.